==> fmdns-3.0.3.tar.gz: facileManager/server/fm-modules/fmDNS/extra/capabilities.inc.php <==
<?php
/*
 +-------------------------------------------------------------------------+
 | Copyright (C) 2013 The facileManager Team                               |
 |                                                                         |
 | This program is free software; you can redistribute it and/or           |
 | modify it under the terms of the GNU General Public License             |
 | as published by the Free Software Foundation; either version 2          |
 | of the License, or (at your option) any later version.                  |
 |                                                                         |
 | This program is distributed in the hope that it will be useful,         |
 | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
 | GNU General Public License for more details.                            |
 +-------------------------------------------------------------------------+
 | facileManager: Easy System Administration                               |
 | fmDNS: Easily manage one or more ISC BIND servers                       |
 +-------------------------------------------------------------------------+
 | http://www.facilemanager.com/modules/fmdns/                             |
 +-------------------------------------------------------------------------+
*/

$fm_user_caps['fmDNS'] = array(
		'view_all'				=> _('View All'),
		'manage_servers'		=> _('Server Management'),
		'build_server_configs'	=> _('Build Server Configs'),
		'manage_zones'			=> _('Zone Management'),
		'manage_records'		=> _('Record Management'),
		'reload_zones'			=> _('Reload Zones'),
		'manage_settings'		=> _('Manage Settings')
	);

==> fmdns-3.3.3.tar.gz: facileManager/server/fm-modules/fmDNS/extra/capabilities.inc.php <==
<?php
/*
 +-------------------------------------------------------------------------+
 | Copyright (C) 2013-2018 The facileManager Team                               |
 |                                                                         |
 | This program is free software; you can redistribute it and/or           |
 | modify it under the terms of the GNU General Public License             |
 | as published by the Free Software Foundation; either version 2          |
 | of the License, or (at your option) any later version.                  |
 |                                                                         |
 | This program is distributed in the hope that it will be useful,         |
 | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
 | GNU General Public License for more details.                            |
 +-------------------------------------------------------------------------+
 | facileManager: Easy System Administration                               |
 | fmDNS: Easily manage one or more ISC BIND servers                       |
 +-------------------------------------------------------------------------+
 | http://www.facilemanager.com/modules/fmdns/                             |
 +-------------------------------------------------------------------------+
*/

$fm_user_caps['fmDNS'] = array(
		'view_all'				=> __('View All'),
		'manage_servers'		=> __('Server Management'),
		'build_server_configs'	=> __('Build Server Configs'),
		'manage_zones'			=> __('Zone Management'),
		'manage_records'		=> __('Record Management'),
		'reload_zones'			=> __('Reload Zones'),
		'manage_settings'		=> _('Manage Settings')
	);
